<?php

namespace Koe\KoeContentmodules\Tests\Unit\Domain\Model;

/***************************************************************
 *  Copyright notice
 *
 *  (c) 2015 Albrecht Köhnlein <typo3@bestof1983.de>
 *
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

/**
 * Test case for class \Koe\KoeContentmodules\Domain\Model\Content.
 *
 * @copyright Copyright belongs to the respective authors
 * @license http://www.gnu.org/licenses/gpl.html GNU General Public License, version 3 or later
 *
 * @author Albrecht Köhnlein <typo3@bestof1983.de>
 */
class ContentTest extends \TYPO3\CMS\Core\Tests\UnitTestCase {
	/**
	 * @var \Koe\KoeContentmodules\Domain\Model\Content
	 */
	protected $subject = NULL;

	protected function setUp() {
		$this->subject = new \Koe\KoeContentmodules\Domain\Model\Content();
	}

	protected function tearDown() {
		unset($this->subject);
	}

	/**
	 * @test
	 */
	public function getModuleDownloadsReturnsInitialValueForModuleDownload() {
		$newObjectStorage = new \TYPO3\CMS\Extbase\Persistence\ObjectStorage();
		$this->assertEquals(
			$newObjectStorage,
			$this->subject->getModuleDownloads()
		);
	}

	/**
	 * @test
	 */
	public function setModuleDownloadsForObjectStorageContainingModuleDownloadSetsModuleDownloads() {
		$moduleDownload = new \Koe\KoeContentmodules\Domain\Model\ModuleDownload();
		$objectStorageHoldingExactlyOneModuleDownloads = new \TYPO3\CMS\Extbase\Persistence\ObjectStorage();
		$objectStorageHoldingExactlyOneModuleDownloads->attach($moduleDownload);
		$this->subject->setModuleDownloads($objectStorageHoldingExactlyOneModuleDownloads);

		$this->assertAttributeEquals(
			$objectStorageHoldingExactlyOneModuleDownloads,
			'moduleDownloads',
			$this->subject
		);
	}

	/**
	 * @test
	 */
	public function addModuleDownloadToObjectStorageHoldingModuleDownloads() {
		$moduleDownload = new \Koe\KoeContentmodules\Domain\Model\ModuleDownload();
		$moduleDownloadsObjectStorageMock = $this->getMock('TYPO3\\CMS\\Extbase\\Persistence\\ObjectStorage', array('attach'), array(), '', FALSE);
		$moduleDownloadsObjectStorageMock->expects($this->once())->method('attach')->with($this->equalTo($moduleDownload));
		$this->inject($this->subject, 'moduleDownloads', $moduleDownloadsObjectStorageMock);

		$this->subject->addModuleDownload($moduleDownload);
	}

	/**
	 * @test
	 */
	public function removeModuleDownloadFromObjectStorageHoldingModuleDownloads() {
		$moduleDownload = new \Koe\KoeContentmodules\Domain\Model\ModuleDownload();
		$moduleDownloadsObjectStorageMock = $this->getMock('TYPO3\\CMS\\Extbase\\Persistence\\ObjectStorage', array('detach'), array(), '', FALSE);
		$moduleDownloadsObjectStorageMock->expects($this->once())->method('detach')->with($this->equalTo($moduleDownload));
		$this->inject($this->subject, 'moduleDownloads', $moduleDownloadsObjectStorageMock);

		$this->subject->removeModuleDownload($moduleDownload);

	}
}
